==> ukui-biometric-auth_1.2.0.orig.tar.gz: ukui-biometric-auth/bioauth/i18n_ts/pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BioAuthWidget</name>
    <message>
        <source>Form</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Mais</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Tente novamente</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation>Impressão digital</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation>FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation>Íris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation>Cara</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation>VoicePrint</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Form</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Device types:</source>
        <translation>Tipos de dispositivos:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Costas</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Está bem</translation>
    </message>
</context>
</TS>

==> ukui-biometric-auth_1.2.2.orig.tar.gz: ukui-biometric-auth/bioauth/i18n_ts/pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BioAuthWidget</name>
    <message>
        <source>Form</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Mais</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Tente novamente</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Current Device: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation>Impressão digital</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation>FingerVein</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation>Íris</translation>
    </message>
    <message>
        <source>Face</source>
        <translation>Cara</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation>VoicePrint</translation>
    </message>
    <message>
        <source>Unplugging of %1 device detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 device insertion detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>biometric</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Form</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Device types:</source>
        <translation>Tipos de dispositivos:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Costas</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Está bem</translation>
    </message>
</context>
</TS>
